@@ -33,15 +33,15 @@ class DatasetBaseHandler:
 @dataclass
 class InputHandler(DatasetBaseHandler):
     type: DatasetInputType
-    shape: Optional[List[int]]
+    shape: Optional[List[int]] = None
 
 
 @dataclass
 class GroundTruthHandler(DatasetBaseHandler):
     type: DatasetOutputType
-    labels: Optional[List[str]]
-    masked_input: Optional[str]
-    shape: Optional[List[int]]
+    labels: Optional[List[str]] = None
+    masked_input: Optional[str] = None
+    shape: Optional[List[int]] = None
 
 
 @dataclass
